@@ -12,6 +12,10 @@ def notify(recipient, tag, subject=None, level=None):
     return Alert.objects.create(**kwargs)
 
 
+def mark_as_read(tag, user):
+    Alert.objects.by_tag(tag).mark_as_read(user)
+
+
 class AlertMessageHandler(object):
     def get_message(self, alert):
         raise NotImplementedError()
